#ifndef _ENDIAN_H_
#define _ENDIAN_H_


#ifdef __cplusplus
extern "C" {
#endif





/* The visible Symbols*/
#define BIG_ENDIAN	__BIG_ENDIAN
#define BYTE_ORDER	__BYTE_ORDER
#define LITTLE_ENDIAN	__LITTLE_ENDIAN



#ifdef __cplusplus
}
#endif
#endif
